function [AT0,AT1,AT2] = shift_uqme(A0,A1,A2,v,lambda,eta)
% [AT0,AT1,AT2]=SHIFT_UQME(A0,A1,A2,v,lambda,eta) applies the shift 
% technique to the UQME A0 + A1 X + A2 X^2 = 0
% A0, A1, A2: matrix coefficients of the UQME
% v, lambda: a column vector and a scalar such that 
% (A0 + lambda*A1 + lambda^2*A2)*v=0 
% eta: a scalar 
% AT0, AT1, AT2: matrix coefficients of the new UQME such that  
% (A0 + eta*A1 + eta^2*A2)*v=0 
p = v/norm(v)^2;
AT2 = A2;
AT1 = A1 + (lambda - eta)*A2*v*p';
AT0 = A0 + (lambda - eta)*(A1 + lambda*A2)*v*p';
